
package landpjava;

import com.ibm.landp.spv.*;
import com.ibm.landp.shfile.*;
import com.ibm.landp.*;
import java.util.*;
import java.io.*;

/**
 * AccessDatabase
 */
public class AccessDatabase implements LandpSPVConst, LandpSHFILEConst {
/**
 * AccessDatabase constructor
 */
public AccessDatabase() {
	super();
}

// Remote request object
public static RmtReq req;

/**
 * Main method
 */
public static void main(String[] args) throws LandpCommunicationException {
	
	// Register with LANDP Java Manager and create RmtReq object
	req = new RmtReq(new Cprb(), RmtReq.MODE_OWN_PID);
	try {
		req.register();
	} catch (Exception e) {
		// Registering failed
	}

	/* Create new instance of SharedFileServer class */
	SharedFileServer server = new SharedFileServer(req);

	// Create instance of Supervisor class
	Supervisor spv = new Supervisor(req);

	try {		
		// Connect to LANDP
		spv.connect();

		String file = "SHFILES1";
		int recordLength = 255;

		// read in the users input
		System.out.println("\nPlease enter the name of the Shared File Database to connect to:\n");
		byte[] input = new byte[20];
        try {
            System.in.read(input);
			String sfs = new String(input).trim();
            if (sfs.length() > 0) file = sfs;
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(-1);
        }
		server.start(file, true);
		
		// Open a shared file session
		String session = server.openSession(true);
		String key = "";
		int n = 0;
		while (server.getSession(session).getSharedFile(n) != null) {		
			key = server.getSession(session).getSharedFile(n).getName();
			System.out.println(n + ":" + '\t' + key);
			n++;
		}

		// read in the users input
		System.out.println("\nPlease enter the name of the key to use:\n");
		input = new byte[20];
		int choice = 0;
		try {
            System.in.read(input);
			String keynum = new String(input).trim();
			choice = (new Integer(keynum)).intValue();
            if (choice < 0) choice = 0;
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(-1);
        }

		// Print out database information related to the chosen key
		System.out.println("Information about shared file " + file + " with key " + server.getSession(session).getSharedFile(choice).getName());
		System.out.println("index pages: " +server.getSession(session).getSharedFile(choice).getIndexPages());
		System.out.println("key is unique: " + server.getSession(session).getSharedFile(choice).getKeyUnique());
		System.out.println("key is variable: " + server.getSession(session).getSharedFile(choice).getKeyVariable());
		System.out.println("Number of used records: " + server.getSession(session).getSharedFile(choice).getLogicalFileSize());
		System.out.println("pointer: " + server.getSession(session).getSharedFile(choice).getPointer()); 
		System.out.println("record length: " + server.getSession(session).getSharedFile(choice).getRecordLength());
		System.out.println("record can be split: " + server.getSession(session).getSharedFile(choice).getRecordSplit());
		System.out.println("split size: " + server.getSession(session).getSharedFile(choice).getRecordSplitSize());
		System.out.println("File name: " + server.getSession(session).getSharedFile(choice).getSharedFileName());
		System.out.println("number of current shared file: " + server.getSession(session).getSharedFile(choice).getSharedFileNumber());
		System.out.println("File path: " + server.getSession(session).getSharedFile(choice).getSharedFilePath());
		System.out.println("File size: " + server.getSession(session).getSharedFile(choice).getSharedFileSize());
		System.out.println("Total files: " + server.getSession(session).getSharedFile(choice).getSharedFileTotal());

		/* Get the next record and display it */
		String record = server.getSession(session).getSharedFile(choice).getRecord(LANDP_S_SHFILE_RECORD_NEXT);
		System.out.println("\nFirst record in database\n" + record);

		// read in the users input
		System.out.println("\nPlease enter the record number to view:\n");
		int recordnum = 5;
		input = new byte[20];
		try {
            System.in.read(input);
			String recnum = new String(input).trim();
			recordnum = (new Integer(recnum)).intValue();
            if (recordnum < 0) choice = 0;
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(-1);
        }
		/* Get and display record n */
		record = server.getSession(session).getSharedFile(choice).getRecord(LANDP_S_SHFILE_ACCESS_DIRECT_INDEXED, 
							LANDP_S_SHFILE_SEARCH_EQUALS, 				// Search mode
							recordnum,									// Record Pointer
							null); 									// Search string
		System.out.println("\nRecord " + recordnum + " in database\n" + record);

		/* Begin an updating transaction */
		server.getSession(session).startTransaction();

		// read in the users input
		System.out.println("\nPlease enter a search string to find a record to lock:\n");
		String search = "";
		input = new byte[20];
        try {
            System.in.read(input);
			search = new String(input).trim();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(-1);
        }
		/* Lock (exclusive use) a record */
		server.getSession(session).getSharedFile(choice).lockRecord(LANDP_S_SHFILE_ACCESS_INDEXED_SEQUENTIAL, 
							LANDP_S_SHFILE_SEARCH_EQUALS,			// Search mode (none)
							0,			// Record Pointer
							search, 	// Search string
							LANDP_S_SHFILE_LOCK_SHARED_FILE);
		System.out.println("\nLock first record containing search string: " + search);


		// read in the users input
		System.out.println("\nPlease enter new data for the record:\n");
		String data = "";
		input = new byte[20];
        try {
            System.in.read(input);
			data = new String(input).trim();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(-1);
        }
		/* Replace record */
		server.getSession(session).getSharedFile(choice).replaceRecord(data);
		System.out.println("\nReplace record data with: " + data);

		// read in the users input
		System.out.println("\nPlease enter data for a new record:\n");
		data = "";
		input = new byte[20];
        try {
            System.in.read(input);
			data = new String(input).trim();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(-1);
        }
		/* Insert record */
		server.getSession(session).getSharedFile(choice).addRecord(data);			// Record data
		System.out.println("\nAdd new record data: " + data);

		/* Checkpoint */
		server.getSession(session).commitTransaction();

		/* End transaction */
		server.getSession(session).endTransaction();

		/* Close the session */
		server.getSession(session).close();

		/* Close shared file */
		server.stop(false);

		// Disconnect from LANDP
		spv.disconnect();

	} catch (LandpSHFILEException e) {
		// deal with exception
		//e.printStackTrace();
		System.err.println(e.getMessage());
		stopTest();
	} catch (LandpSPVException e) {
		// deal with exception
		e.printStackTrace();
		System.err.println(e.getMessage());
		stopTest();
	}

	stopTest();
} // end main method

public static void stopTest() {
	// Unregister with LANDP Java Manager
	try {
		req.unregister();
	} catch (Exception e) {
		// Unregistering failed
	}

}

} // end of code