
package landpjava;

import com.ibm.landp.spv.*;
import com.ibm.landp.*;
import java.util.*;

/**
 * SimpleSupervisor
 */
public class SimpleSupervisor implements LandpSPVConst {
/**
 * SimpleSupervisor constructor
 */
public SimpleSupervisor() {
	super();
}

// Remote request object
public static RmtReq req;

/**
 * Main method
 */
public static void main(String[] args) throws LandpCommunicationException {
	
	//Register with LANDP Java Manager and create RmtReq object
	req = new RmtReq(new Cprb(), RmtReq.MODE_OWN_PID);
	try {
		req.register();
	} catch (Exception e) {
		// Registering failed
	}

	// Create instance of Supervisor class
	Supervisor spv = new Supervisor(req);

	try {		
		// Connect to LANDP
		spv.connect();

		// Get system details
		Vector sitest = spv.systemStatus();
		String output = "Process" + '\t' + "Service Name"+ '\t' + "Alias Name"+ '\t' + "PID"+ '\t' + "WSID" + '\t' + "OS"+ '\t' + "Access" + '\t' + "Connect" + '\t' + "Process Type";
		System.out.println(output);

		// Print out system information
		for (int i = 0; i < sitest.size(); i++) { 
			LandpLoadTable table = (LandpLoadTable)sitest.elementAt(i);
			output = "" + i 
						+ '\t' + table.getProcessName() 
						+ '\t' + table.getProcessAliasName()
						+ '\t' + table.getProcessIdent()
						+ '\t' + table.getProcessLoc();

			// Get operating system information
	        switch(table.getProcessOpSys()) {
				case LANDP_SPV_OS_DOS:
					output += '\t' + "DOS";
					break;
				case LANDP_SPV_OS_OS2:
					output += '\t' + "OS/2";
					break;
				case LANDP_SPV_OS_NT:
					output += '\t' + "NT";
					break;
				default:
					output += '\t' + "INVALID";
			}

			// Get access, connect and process status
			if (table.getProcessAccessType() == LANDP_SPV_LOCAL) output += '\t' + "LOCAL";
			if (table.getProcessAccessType() == LANDP_SPV_NOT_LOCAL) output += '\t' + "REMOTE";
			if (table.getProcessConnectStatus() == LANDP_SPV_ONLINE) output += '\t' + "ONLINE";
			if (table.getProcessConnectStatus() == LANDP_SPV_OFFLINE) output += '\t' + "OFFLINE";
			if (table.getProcessType() == LANDP_SPV_SERVICE) output += '\t' + "SERVICE";
			if (table.getProcessType() == LANDP_SPV_APPLICATION) output += '\t' + "APP";

			// Print out the results
			System.out.println(output);

		}                
	  
		// Print out local pc information
		System.out.println("pc id = " + spv.getPcid());
		System.out.println("pc type = " + spv.getPctype());
		System.out.println("lan id = " + spv.getLanid());
		System.out.println("landp version = " + spv.getLandpProgramVersion());

		// Disconnect from LANDP
		spv.disconnect();

	} catch (LandpSPVException e) {
		// deal with exception
		e.printStackTrace();
	}

	// Unregister with LANDP Java Manager
	try {
		req.unregister();
	} catch (Exception e) {
		// Unregistering failed
	}

} // end main method

} // end of code