
package landpjava;

import com.ibm.landp.spv.*;
import com.ibm.landp.sna.*;
import com.ibm.landp.*;
import java.util.*;

/**
 * TalkToHost
 */
public class TalkToHost implements LandpSPVConst {
/**
 * TalkToHost constructor
 */
public TalkToHost() {
	super();
}

// Remote request object
public static RmtReq req;

/**
 * Main method
 */
public static void main(String[] args) throws LandpCommunicationException {
	
	// Register with LANDP Java Manager and create RmtReq object
	req = new RmtReq(new Cprb(), RmtReq.MODE_OWN_PID);
	try {
		req.register();
	} catch (Exception e) {
		// Registering failed
	}

	// Create new instance of SNAServer class
	SNAserver server = new SNAserver(req);

	// Create instance of Supervisor class
	Supervisor spv = new Supervisor(req);

	try {		
		// Connect to LANDP
		spv.connect();

		// Open a new session - e.g. session SNA01
		String sessionNumber = "SNA01";
		int timeout = 30; // Timeout value = 30 seconds

		// read in the users input
		System.out.println("\nPlease enter the name of the SNA session to connect to:\n");
        try {
            String session = System.in.read();
            if (session.length() > 0) sessionNumber = session;
        } catch(IOException e) {
            e.printStackTrace();
            System.exit(-1);
        }

		server.openSessionSNA(sessionNumber, timeout);
		
		// Display messages from the host
		while (server.getMessageStatus(sessionNumber))	{
			HostMessage message = server.getSessionSNA(sessionNumber).readHostMessage();
			System.out.println("Message: " + message.getText().trim());
		}

		/* Open an LU-LU connection with an application on the host */		
		String applName = "IYCKZCDA"; // Host application name

		// read in the users input
		System.out.println("\nPlease enter the name of the host application to connect to:\n");
        try {
            String appl = System.in.read();
            if (appl.length() > 0) applName = appl;
        } catch(IOException e) {
            e.printStackTrace();
            System.exit(-1);
        }
		server.getSessionSNA(sessionNumber).openLU(true, applName, timeout);

		// Display messages from the host
		while (server.getMessageStatus(sessionNumber))	{
			HostMessage openMessage = server.getSessionSNA(sessionNumber).readHostMessage();
			System.out.println("Message: " + openMessage.getText().trim());
		}

		/* Create a new message and send it to the host */
		String message = new String("TMA4S1L20***********");

		// read in the users input
		System.out.println("\nPlease enter the message to send:\n");
        try {
            String mess = System.in.read();
            if (mess.length() > 0) message = mess;
        } catch(IOException e) {
            e.printStackTrace();
            System.exit(-1);
        }
		HostMessage sendMessage = new HostMessage(message);
		server.getSessionSNA(sessionNumber).sendHostMessage(sendMessage);

		/* Wait for host to generate response */
		spv.waitForEvent(new Vector(), LANDP_SPV_SET_TIMEOUT, 0, 0, timeout);
		
		/* Read the response from the host and display it */
		while (server.getMessageStatus(sessionNumber))	{
			HostMessage readMessage = server.getSessionSNA(sessionNumber).readHostMessage();
			System.out.println("Message: " + readMessage.getText().trim());
		}

		/* Close the LU-LU session */
		server.getSessionSNA(sessionNumber).closeLU(applName, timeout);

		/* Close the SNA session */
		server.closeSessionSNA(sessionNumber);

		// Disconnect from LANDP
		spv.disconnect();

	} catch (LandpSNAException e) {
		// deal with exception
		e.printStackTrace();
		stopTest();
	} catch (LandpSPVException e) {
		// deal with exception
		e.printStackTrace();
		stopTest();
	}

	stopTest();
} // end main method

public static void stopTest() {

	// Unregister with LANDP Java Manager
	try {
		req.unregister();
	} catch (Exception e) {
		// Unregistering failed
	}

}

} // end of code